
from setuptools import setup
import os
import re

def read_version():
    source_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'cedexis/radar/__init__.py')
    with open(source_path) as fp:
        source = fp.read()
    major_match = re.search('__sampler_major_version__\s+=\s+(\d+)', source)
    minor_match = re.search('__sampler_minor_version__\s+=\s+(\d+)', source)
    micro_match = re.search('__sampler_micro_version__\s+=\s+(\d+)', source)
    return '{}.{}.{}'.format(
        major_match.group(1),
        minor_match.group(1),
        micro_match.group(1),
    )

def read_file(file_path):
    """
    Read a file relative to the directory containing this file
    """
    root_dir = os.path.dirname(os.path.abspath(__file__))
    file_path = os.path.join(root_dir, file_path)
    with open(file_path) as fp:
        return fp.read().decode('utf-8').strip()

# See http://docs.python.org/3.3/distutils/apiref.html#module-distutils.core
# for help with setup keyword arguments
setup_kwargs = {
    # http://www.python.org/dev/peps/pep-0423/#use-a-single-name
    'name': 'cedexis.radar',
    'version': read_version(),
    'description': 'Cedexis Radar client library',
    'long_description': '\n\n'.join([
        read_file('README.rst'),
    ]),
    'classifiers': [
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: IronPython',
        'Topic :: Internet',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    'keywords': [
        'cedexis',
        'radar',
        'internet',
        'dns',
        'cdn',
        'cloud',
        'load balancing',
        'availability',
        'rtt',
    ],
    'url': 'https://github.com/cedexis/python-radar',
    'author': 'Jacob Wan',
    'author_email': 'jacob@wildlemur.com',
    'license': 'MIT',
    'packages': [
        'cedexis',
        'cedexis.radar',
        'cedexis.radar.session',
        'cedexis.radar.session.uni',
    ],
    'namespace_packages': [
        'cedexis',
    ],
    'tests_require': [
        'nose'
    ],
    'test_suite': 'nose.collector',
    'entry_points': {
        'console_scripts': [
            'cedexis-radar-cli=cedexis.radar.cli:main',
        ],
    },
    'include_package_data': True,
    'zip_safe': False,
}

setup(**setup_kwargs)
